package router

import (
	"github.com/gin-gonic/gin"
	"icloudapp.cn/tools/admin"
	"icloudapp.cn/tools/controller"
	"icloudapp.cn/tools/middleware"
	"net/http"
)

func SetupApiRouters(r *gin.Engine) {
	r.StaticFS("/upload", http.Dir("./upload"))

	v1 := r.Group("/api/v1")
	v1.Use(middleware.AuthMiddleware())
	/*
		v1.GET("pipeline/:id", controller.GetPipelineDetailHandler)
		v1.GET("pipeline", controller.GetPipelineListHandler)
		v1.POST("pipeline", controller.CreatePipelineHandler)
		v1.PUT("pipeline", controller.UpdatePipelineHandler)
		v1.DELETE("pipeline/:id", controller.DeletePipelineHandler)
	*/
	r.GET("/index", controller.Index)

	userApi := r.Group("/api/user")
	userApi.GET("/login", controller.Login)
	userApi.POST("/login", controller.Login)
	userApi.GET("/register", controller.Register)
	userApi.POST("/register", controller.Register)

	userApiNeedLogin := r.Group("api/user")
	userApiNeedLogin.Use(middleware.JWTAuthMiddleware())
	userApiNeedLogin.GET("/info", controller.Info)
	userApiNeedLogin.GET("/refresh_token", controller.RefreshToken)

	userApiNeedLogin.GET("/changepwd", controller.ChangePassword)
	userApiNeedLogin.POST("/changepwd", controller.ChangePassword)

	userApiNeedLogin.GET("/change_email", controller.ChangeEmail)
	userApiNeedLogin.POST("/change_email", controller.ChangeEmail)

	poster := r.Group("/api/poster")
	poster.GET("/info", controller.PosterInfo)
	poster.GET("/image", controller.Image)
	poster.GET("/cut", controller.Cut)
	poster.GET("/save", middleware.JWTAuthMiddleware(), controller.SavePoster)
	poster.GET("/preview", controller.Preview)
	poster.GET("/draw", controller.DrawImage)

	adminApi := r.Group("api/admin")
	adminApi.Use(middleware.JWTAuthMiddleware())
	adminApi.Use(middleware.RoleMiddleWare())
	adminApi.POST("/upload/material", admin.Material)
	adminApi.POST("/upload/fonts", admin.Font)

	uploadApi := r.Group("/api/upload")
	uploadApi.POST("/material", middleware.RoleMiddleWare(), admin.Material)
	uploadApi.POST("/fonts", middleware.RoleMiddleWare(), admin.Font)

}
